@@ -258,7 +258,7 @@ class Update(Task):
             for elem in body.get("data"):
                 rec = Record()
                 rec.set_id(elem.get("id"))
-                elem.remove("id")
+                elem.pop("id")
                 for key in elem:
                     rec.add_key_value(key, elem.get(key))
                 records.append(rec)
